@@ -363,41 +363,10 @@ fn trim_all(text: &[u8]) -> Cow<'_, [u8]> {
 /// Removes excess spaces before and after a given byte string by returning a subset of those bytes.
 /// Will return an empty slice if a string is composed entirely of whitespace.
 fn trim_spaces_from_byte_string(bytes: &[u8]) -> &[u8] {
-    if bytes.is_empty() {
-        return bytes;
-    }
-
-    let mut starting_index = 0;
-
-    for i in 0..bytes.len() {
-        // If we get to the end of the array without hitting a non-whitespace char, return empty slice
-        if i == bytes.len() - 1 {
-            // This range equates to an empty slice
-            return &bytes[0..0];
-        // otherwise, skip over each instance of whitespace
-        } else if bytes[i] == b' ' {
-            continue;
-        }
-
-        // return the index of the first non-whitespace character
-        starting_index = i;
-        break;
-    }
-
-    // Now we do the same but in reverse
-    let mut ending_index = 0;
-    for i in (0..bytes.len()).rev() {
-        // skip over each instance of whitespace
-        if bytes[i] == b' ' {
-            continue;
-        }
-
-        // return the index of the first non-whitespace character
-        ending_index = i;
-        break;
-    }
-
-    &bytes[starting_index..=ending_index]
+    let starting_index = bytes.iter().position(|b| *b != b' ').unwrap_or(0);
+    let ending_offset = bytes.iter().rev().position(|b| *b != b' ').unwrap_or(0);
+    let ending_index = bytes.len() - ending_offset;
+    &bytes[starting_index..ending_index]
 }
 
 /// Works just like [trim_all] but acts on HeaderValues instead of bytes
@@ -757,6 +726,11 @@ mod tests {
         assert_eq!(expected, actual);
     }
 
+    #[test]
+    fn trim_spaces_works_on_single_characters() {
+        assert_eq!(trim_all(b"2").as_ref(), b"2");
+    }
+
     proptest! {
         #[test]
         fn test_trim_all_doesnt_elongate_strings(s in ".*") {
@@ -771,5 +745,10 @@ mod tests {
         fn test_normalize_header_value_doesnt_panic(v in (".*").prop_filter_map("Must be a valid HeaderValue", |v| http::HeaderValue::from_maybe_shared(v).ok())) {
             let _ = normalize_header_value(&v);
         }
+
+        #[test]
+        fn test_trim_all_does_nothing_when_there_are_no_spaces(s in "[^ ]*") {
+            assert_eq!(trim_all(s.as_bytes()).as_ref(), s.as_bytes());
+        }
     }
 }
